import z from "zod"

const groundType=z.enum(["HEAVY", "MEDIUM", "LIGHT"])
const waterDemand=z.enum(["DRY","WET","VERY_WET"])
const lightingDemand=z.enum(["LOW","MEDIUM","HIGH"])
const nutrientDemand=z.enum(["LOW","MEDIUM","HIGH"])
const weekNumber= z.number().int().min(0).max(51)

export const PlantSchema = z.object({
    id: z.number(),
    name: z.string(),
    latinName: z.string().nullable(),
    description: z.string().nullable(),
    origin: z.string().nullable(),
    growingTips: z.string().nullable(),
    plantWeekStart: z.number().int().positive().nullable(),
    plantWeekEnd: z.number().int().positive().nullable(),
    harvestWeekStart: z.number().int().positive().nullable(),
    harvestWeekEnd: z.number().int().positive().nullable(),
    groundType: groundType.transform(s => translateGroundType(s)).nullable(),
    waterDemand: waterDemand.transform(s=>translateWaterDemand(s)).nullable(),
    lightingDemand: lightingDemand.transform(s=>translateLightingDemand(s)).nullable(),
    nutrientDemand: nutrientDemand.transform(s=>translateNutrientDemand(s)).nullable(),
    imageUrl: z.string().optional()
  });
  
  export type Plant = z.infer<typeof PlantSchema>;

  function translateLightingDemand(key: "LOW"|"MEDIUM"|"HIGH"){
    const map = {
        LOW: "Niedrig",
        MEDIUM: "Mittel",
        HIGH: "Hoch"
    } 
    return map[key];
  }

  function translateGroundType(key: "HEAVY" | "MEDIUM" | "LIGHT") {
    const map = {
        HEAVY: "Schwer",
        MEDIUM: "Mittel",
        LIGHT: "Leicht"
    } 
    return map[key];
  }

  function translateWaterDemand(key: "DRY"|"WET"|"VERY_WET"){
    const map = {
        DRY: "Trocken",
        WET: "Feucht",
        VERY_WET: "Sehr feucht"
    } 
    return map[key];
  }

  function translateNutrientDemand(key: "LOW"|"MEDIUM"|"HIGH"){
    const map = {
        LOW: "Nierig",
        MEDIUM: "Mittel",
        HIGH: "Hoch"
    } 
    return map[key];
  }

  export const SearchRequestSchmema= z.object({
    searchTerm: z.string().optional(),
    waterDemand: waterDemand.optional(),
    nutrientDemand: nutrientDemand.optional(),
    groundType: groundType.optional(),
    lightingDemand: lightingDemand.optional(),
    plantWeekStart: weekNumber.optional(),
    plantWeekEnd: weekNumber.optional(),
    growthDurationMin: weekNumber.optional(),
    growthDurationMax: weekNumber.optional()
  })

  export type searchRequest = z.infer<typeof SearchRequestSchmema>;


